@@ -6,31 +6,37 @@
 # LICENSE.txt for the terms of this license.
 #
 #####################################################################
-__version__='$Revision: 1.9 $'[11:-2]
+__version__='$Revision: 1410 $'[11:-2]
 
 # General Python imports
-import os, urllib, time
+import logging
+import os
+from sets import Set
+import time
+import urllib
 
 # Zope imports
-from Globals import package_home, InitializeClass, MessageDialog, DTMLFile
-from Acquisition import aq_base
 from AccessControl import ClassSecurityInfo
-from AccessControl.Permissions import view_management_screens, manage_users
+from AccessControl.Permissions import manage_users
+from AccessControl.Permissions import view_management_screens
 from AccessControl.SpecialUsers import emergency_user
-from OFS.SimpleItem import SimpleItem
+from Acquisition import aq_base
 from DateTime.DateTime import DateTime
+from Globals import DTMLFile
+from Globals import InitializeClass
+from Globals import MessageDialog
+from Globals import package_home
+from OFS.SimpleItem import SimpleItem
 
 # LDAPUserFolder package imports
-from LDAPUser import LDAPUser
-from LDAPDelegate import explode_dn, ADD, DELETE
-from utils import GROUP_MEMBER_MAP
-from SimpleLog import SimpleLog
-from SharedResource import getResource
-
+from Products.LDAPUserFolder.LDAPDelegate import filter_format
+from Products.LDAPUserFolder.SharedResource import getResource
+from Products.LDAPUserFolder.utils import GROUP_MEMBER_MAP
 
 _dtmldir = os.path.join(package_home(globals()), 'dtml')
 addLDAPUserSatelliteForm = DTMLFile('addLDAPUserSatellite', _dtmldir)
 CHANGE_LUF_PERMISSION = 'Change user folder'
+logger = logging.getLogger('event.LDAPUserSatellite')
 
 
 class LDAPUserSatellite(SimpleItem):
@@ -58,8 +64,6 @@ class LDAPUserSatellite(SimpleItem):
          'help'  : ('LDAPUserFolder','ConfigureSatellite.stx')},
         {'label' : 'Caches', 'action' : 'manage_cache',
          'help'  : ('LDAPUserFolder', 'CachesSatellite.stx')},
-        {'label' : 'Log', 'action' : 'manage_log',
-         'help'  : ('LDAPUserFolder', 'LogSatellite.stx')},
         )
         + SimpleItem.manage_options
         ) 
@@ -69,9 +73,6 @@ class LDAPUserSatellite(SimpleItem):
     manage = manage_main = DTMLFile('dtml/sat_properties', globals())
     manage_main._setName('manage_main')
     
-    security.declareProtected(view_management_screens, 'manage_log')
-    manage_log = DTMLFile('dtml/sat_log', globals())
-
     security.declareProtected(view_management_screens, 'manage_cache')
     manage_cache = DTMLFile('dtml/sat_cache', globals())
 
@@ -88,19 +89,9 @@ class LDAPUserSatellite(SimpleItem):
         LDAPUserSatellite.inheritedAttribute('__setstate__')(self, v)
         self._clearCaches()
 
-        # "Upgrade" the log attribute if needed
-        if hasattr(self, '_log') and isinstance(self._log, SimpleLog):
-            del self._log
-
         if not hasattr(self, '_hash'):
             self._hash = '%s%s' % (self.meta_type, str(time.time()))
 
-        if not hasattr(self, 'verbose'):
-            self.verbose = 2
-
-        if self.verbose > 2:
-            self._log().log(3,'Re-initialized through __setstate__')
-
 
     def __init__(self, luf, title='', recurse=0):
         """ Create a new LDAPUserSatellite instance """
@@ -108,7 +99,6 @@ class LDAPUserSatellite(SimpleItem):
         self.title = title
         self.recurse = recurse
         self._luf = luf
-        self.verbose = 2    # _log needs it
         self.groups_base = ''
         self.groups_scope = ''
         self.groups_map = {}
@@ -119,14 +109,13 @@ class LDAPUserSatellite(SimpleItem):
         """ Clear all logs and caches for user-related information """
         self._cache('users').clear() # Cache for user ID - role mapping
         self._cache('expiration').clear() # Cache user ID - expiration mapping
-        self._log().clear()
 
 
     security.declareProtected(manage_users, 'manage_reinit')
     def manage_reinit(self, REQUEST=None):
         """ re-initialize and clear out users and log """
         self._clearCaches()
-        self.verbose > 1 and self._log().log(2, 'Reinitialized')
+        logger.info('manage_reinit: Cleared caches')
 
         if REQUEST:
             msg = 'User caches cleared'
@@ -138,7 +127,6 @@ class LDAPUserSatellite(SimpleItem):
                    , luf
                    , groups_base
                    , groups_scope
-                   , verbose=2
                    , title=''
                    , recurse=0
                    , REQUEST=None 
@@ -146,7 +134,6 @@ class LDAPUserSatellite(SimpleItem):
         """ Edit the LDAPUserSatellite Object """
         self.title = title
         self.recurse = recurse
-        self.verbose = verbose
         self.groups_base = groups_base
         self.groups_scope = groups_scope
 
@@ -214,12 +201,15 @@ class LDAPUserSatellite(SimpleItem):
 
         if ( self._cache('users').has_key(user_id) and
              self._cache('expiration').get(user_id, 0) >= user_expiration ):
-            self.verbose > 6 and self._log().log(7, 'Used cached "%s"' % user_id)
+            logger.debug('Used cached user "%s"' % user_id)
             return self._cache('users').get(user_id)
 
         if self.groups_base:   # We were given a search base, so search there
             user_dn = user.getUserDN()
-            group_filter = '(|(uniquemember=%s)(member=%s))' % (user_dn, user_dn)
+            member_attrs = list(Set(GROUP_MEMBER_MAP.values()))
+            filt_list = [ filter_format('(%s=%s)', (m_attr, user_dn))
+                                        for m_attr in member_attrs ]
+            group_filter = '(|%s)' % ''.join(filt_list)
 
             res = luf._delegate.search( self.groups_base
                                       , self.groups_scope
@@ -234,7 +224,7 @@ class LDAPUserSatellite(SimpleItem):
                     try:
                         cn = resultset[i].get('cn')[0]
                     except KeyError:    # NDS oddity
-                        cn = explode_dn(dn, 1)[0]
+                        cn = luf._delegate.explode_dn(dn, 1)[0]
 
                     add_role_dict[cn] = 1
 
@@ -243,21 +233,22 @@ class LDAPUserSatellite(SimpleItem):
         already_added = ()
 
         if self.groups_map:     # We have a group mapping, so map away
-            roles = list(user.getRoles())
+            user_roles = list(user.getRoles())
+            roles = user_roles[:]
             roles.extend(add_role_dict.keys())
+            roles.extend(list(user._getLDAPGroups()))
 
             for role in roles:
                 mapped_roles = self.groups_map.get(role, [])
                 for mapped_role in mapped_roles:
-                    if mapped_role:
+                    if mapped_role and mapped_role not in user_roles:
                         add_role_dict[mapped_role] = 1
 
         added_roles = add_role_dict.keys()
 
-        if added_roles and self.verbose > 4:
+        if added_roles:
             add_roles = ', '.join(added_roles)
-            msg = 'Added roles %s to user %s' % (add_roles, user_id)
-            self._log().log(5, msg)
+            logger.debug('Added roles "%s" to user "%s"' % (add_roles, user_id))
 
         self._cacheRoles(user_id, added_roles, user_expiration)
 
@@ -299,7 +290,17 @@ class LDAPUserSatellite(SimpleItem):
 
         if self.groups_base:
             no_show = ('Anonymous', 'Authenticated', 'Shared')
-            group_filter = '(|(uniquemember=%s)(member=%s))' % (dn, dn)
+
+            if dn == '*':
+                group_classes = GROUP_MEMBER_MAP.keys()
+                filt_list = [ filter_format('(%s=%s)', ('objectClass', g))
+                                        for g in group_classes ]
+                group_filter = '(|%s)' % ''.join(filt_list)
+            else:
+                member_attrs = list(Set(GROUP_MEMBER_MAP.values()))
+                filt_list = [ filter_format('(%s=%s)', (m_attr, dn))
+                                            for m_attr in member_attrs ]
+                group_filter = '(|%s)' % ''.join(filt_list)
             luf = self.getLUF()
 
             res = luf._delegate.search( self.groups_base
@@ -315,7 +316,7 @@ class LDAPUserSatellite(SimpleItem):
                     try:
                         cn = resultset[i].get('cn')[0]
                     except KeyError:    # NDS oddity
-                        cn = explode_dn(dn, 1)[0]
+                        cn = luf._delegate.explode_dn(dn, 1)[0]
 
                     if attr is None:
                         group_list.append((cn, dn))
@@ -335,8 +336,8 @@ class LDAPUserSatellite(SimpleItem):
 
         res = luf._delegate.search( self.groups_base
                                   , self.groups_scope
-                                  , 'cn=%s' % cn
-                                  , ['uniqueMember', 'member']
+                                  , '(cn=%s)' % cn
+                                  , list(Set(GROUP_MEMBER_MAP.values()))
                                   )
 
         if res['exception']:
@@ -354,7 +355,7 @@ class LDAPUserSatellite(SimpleItem):
         all_dns = {}
         users = []
         luf = self.getLUF()
-        possible_members = GROUP_MEMBER_MAP.values()
+        possible_members = list(Set(GROUP_MEMBER_MAP.values()))
 
         if groups is None:
             groups = self.getGroups()
@@ -392,7 +393,7 @@ class LDAPUserSatellite(SimpleItem):
             if role_dn not in all_groups:
                 newgroup_type = 'groupOfUniqueNames'
                 newgroup_member = GROUP_MEMBER_MAP.get(newgroup_type)
-                newgroup_name = explode_dn(role_dn, 1)[0]
+                newgroup_name = luf._delegate.explode_dn(role_dn, 1)[0]
                 connection = luf._connect()
                 attr_list = [ ('objectClass', ['top', newgroup_type])
                             , ('cn', newgroup_name)
@@ -403,12 +404,12 @@ class LDAPUserSatellite(SimpleItem):
 
         for group in all_groups:
             if group in cur_groups and group not in role_dns:
-                operations.append({ 'op'     : DELETE
+                operations.append({ 'op'     : luf._delegate.DELETE
                                   , 'target' : group
                                   , 'type'   : luf.getGroupType(group)
                                   } )
             elif group in role_dns and group not in cur_groups:
-                operations.append({ 'op'     : ADD
+                operations.append({ 'op'     : luf._delegate.ADD
                                   , 'target' : group
                                   , 'type'   : luf.getGroupType(group)
                                   } )
@@ -452,11 +453,6 @@ class LDAPUserSatellite(SimpleItem):
             del self._cache('expiration')[name]
 
 
-    def getLog(self):
-        """ Get the log for displaying """
-        return self._log().getLog()
-
-
     security.declareProtected(manage_users, 'getGroupMappings')
     def getGroupMappings(self):
         """ Return the dictionary that maps LDAP groups map to Zope roles """
@@ -500,12 +496,6 @@ class LDAPUserSatellite(SimpleItem):
             return self.manage_main(manage_tabs_message=msg)
 
 
-    security.declarePrivate('_log')
-    def _log(self):
-        """ Get the shared log resource """
-        return getResource('%s-log' % self._hash, SimpleLog, ())
-
-
     security.declarePrivate('_cache')
     def _cache(self, cache_type='users'):
         """ Get the specified user cache """
