@@ -6,10 +6,14 @@
 # LICENSE.txt for the terms of this license.
 #
 #####################################################################
+__version__='$Revision: 1402 $'[11:-2]
 
-import sha
-from binascii import b2a_base64, a2b_base64
+from binascii import a2b_base64
+from binascii import b2a_base64
+from binascii import Error as binascii_Error
 from random import randrange
+import sha
+
 
 """
 SSHA is a modification of the SHA digest scheme with a salt
@@ -41,7 +45,7 @@ def encrypt(password):
 def validate(reference, attempt):
     try:
         ref = a2b_base64(reference)
-    except binascii.Error:
+    except binascii_Error:
         # Not valid base64.
         return 0
 
