@@ -3,11 +3,6 @@
 ##
 from Products.CMFCore.utils import getToolByName
 from Products.CMFDefault.permissions import ManageUsers
-try:
-    from Products.CMFDefault.utils import MessageID as _
-except:
-    # BBB Zope 2.7
-    _ = str
 
 mtool = getToolByName(script, 'portal_membership')
 mdtool = getToolByName(script, 'portal_memberdata')
@@ -36,6 +31,6 @@ else:
     if ptool.getProperty('validate_email') or send_password:
         rtool.registeredNotify(member_id)
     if mtool.checkPermission(ManageUsers, mtool):
-        return context.setStatus(True, _('Member registered.'))
+        return context.setStatus(True, 'Member registered.')
     else:
-        return context.setStatus(False, _('Success!'))
+        return context.setStatus(False, 'Success!')
