@@ -6,22 +6,18 @@
 # LICENSE.txt for the terms of this license.
 #
 #####################################################################
-__version__='$Revision: 1333 $'[11:-2]
+__version__='$Revision: 1402 $'[11:-2]
 
 # General Python imports
-import unittest
 import doctest
-import sys
+import unittest
 
 # Zope imports
 from AccessControl.SecurityManagement import newSecurityManager
 from AccessControl.SecurityManagement import noSecurityManager
 
 import Testing
-try:
-    import Zope2
-except ImportError: # BBB: for Zope 2.7
-    import Zope as Zope2
+import Zope2
 Zope2.startup()
 
 # LDAPUserFolder package imports
@@ -862,6 +858,53 @@ class TestLDAPUserFolder(LDAPTest):
         for attr in attributes:
             self.failUnless(res.has_key(attr))
 
+    def testGroupLifecycle_nonutf8(self):
+        # http://www.dataflake.org/tracker/issue_00527
+        # Make sure groups with non-UTF8/non-ASCII characters can be
+        # added and deleted.
+        groupid = 'gr\xc3\xbcppe' # Latin-1 Umlaut-U
+        acl = self.folder.acl_users
+
+        # Add the group with the odd character in it
+        acl.manage_addGroup(groupid)
+        all_groups = acl.getGroups()
+
+        # Only one group record should exist, the one we just entered
+        self.failUnless(len(all_groups) == 1)
+        self.failUnless(all_groups[0][0] == groupid)
+
+        # Now delete the group. The DN we get back from getGroups will have been
+        # recoded into whatever is set in utils.py (normally latin-1). Due to
+        # a lack of encoding into UTF-8 in the deletion code, the deletion
+        # would fail silently and the group would still exist.
+        group_dn = all_groups[0][1]
+        acl.manage_deleteGroups(dns=[group_dn])
+        self.failUnless(len(acl.getGroups()) == 0)
+
+    def testGroupsWithCharactersNeedingEscaping(self):
+        # http://www.dataflake.org/tracker/issue_00507
+        # Make sure groups with hash characters can be
+        # added, deleted and used
+        groupid = '#APPLIKATIONEN LAUFWERK(a)#'
+        acl = self.folder.acl_users
+
+        # Add the group with the odd character in it
+        acl.manage_addGroup(groupid)
+        all_groups = acl.getGroups()
+
+        # Only one group record should exist, the one we just entered
+        self.failUnless(len(all_groups) == 1)
+        self.failUnless(all_groups[0][0] == groupid)
+
+        # Now delete the group.
+        group_dn = all_groups[0][1]
+        # XXX Shortcoming in FakeLDAP: DNs are not "unescaped", meaning escaping
+        # done during insertion will be retained in the real record, unlike
+        # a real LDAP server which will store and return unescaped DNs.
+        group_dn = group_dn.replace('\\', '')
+        acl.manage_deleteGroups(dns=[group_dn])
+        self.failUnless(len(acl.getGroups()) == 0)
+        
 
 def test_suite():
     suite = unittest.TestSuite()
