@@ -7,18 +7,16 @@
 # LICENSE.txt for the terms of this license.
 #
 ######################################################################
-__version__='$Revision: 1333 $'[11:-2]
+__version__='$Revision: 1402 $'[11:-2]
 
-import urllib
-import sha
-import SSHA
-import md5
-import random
 import base64
 import codecs
-import string
-
+import md5
+import random
 from sets import Set
+import sha
+import SSHA
+import string
 
 #################################################
 # "Safe" imports for use in the other modules
@@ -26,10 +24,8 @@ from sets import Set
 
 try:
     import crypt
-    HAVE_CRYPT = 1
 except ImportError:
     crypt = None
-    HAVE_CRYPT = 0
 
 #################################################
 # Constants used in other modules
@@ -69,7 +65,7 @@ def _verifyUnicode(st):
         try:
             return unicode(st)
         except UnicodeError:
-            return unicode(st, encoding).encode(encoding)
+            return unicode(st, encoding)
 
 
 def _createLDAPPassword(password, encoding='SHA'):
